@@ -1,5 +1,6 @@
 from oda_data import config
 from oda_data.get_data import common
+from oda_data.logger import logger
 
 
 def download_dac1(small_version: bool = False) -> None:
@@ -9,7 +10,7 @@ def download_dac1(small_version: bool = False) -> None:
     Args:
         small_version: optionally save a smaller version of the file with only key
             columns (default is False)."""
-
+    logger.info(f"Downloading DAC1 data... This may take a while.")
     common.download_single_table(
         bulk_url=config.TABLE1_URL,
         raw_file_name="Table1_Data.csv",
