@@ -1,6 +1,7 @@
 from oda_data import config
 
 from oda_data.get_data import common
+from oda_data.logger import logger
 
 
 def download_dac2a(small_version: bool = False) -> None:
@@ -10,7 +11,7 @@ def download_dac2a(small_version: bool = False) -> None:
     Args:
         small_version: optionally save a smaller version of the file with only key
             columns (default is False)."""
-
+    logger.info(f"Downloading DAC2A data... This may take a while.")
     common.download_single_table(
         bulk_url=config.TABLE2A_URL,
         raw_file_name="Table2a_Data.csv",
